@@ -195,7 +195,7 @@ class Graph(object):
 
     def __str__(self):
         result = str()
-        result += '\n' + self.id + ':'
+        result += '\n' + self.uri + ':'
         triples = self.to_dict()
         for s in triples:
             result += '\n - ' + str(s) + ':'
